@@ -28,7 +28,7 @@ BEGIN {
 
 our @ISA = q(Exporter);
 our @EXPORT = qw($config $logger $zx_api);
-our $VERSION = q(0.03);
+our $VERSION = q(0.04);
 
 our $config = {};
 our $logger;
@@ -335,6 +335,19 @@ Zabbix::ServerScript is a module to simplify writing new scripts for Zabbix serv
 
 =head2 init($opt)
 
+Accepts hashref as an argument, which can have the following keys:
+	
+	$opt = {
+		config => q(path/to/local/config.yaml),
+		console => 0, 				# should the script log to STDERR or not
+		verbose => 0, 				# increase verbosity. By default, script will log only WARN messages and above.
+		debug => 0, 				# Enable debug mode.
+		logger => q(Zabbix.ServerScript), 	# Log4perl logger name
+		api => q(),				# name of Zabbix API instance in global config
+		id => q(),	 			# unique identifier of what is being done, e.g.: database being checked
+		unique => 1, 				# only one instance for each $opt->{id} is allowed
+	}
+
 Initializes following global variables: 
 
 =over 4
@@ -374,19 +387,6 @@ Zabbix::ServerScript::API object
 
 =back
 
-init() accepts hashref as an argument, which can have the following keys:
-	
-	$opt = {
-		config => q(path/to/local/config.yaml),
-		console => 0, 				# should the script log to STDERR or not
-		verbose => 0, 				# increase verbosity. By default, script will log only WARN messages and above.
-		debug => 0, 				# Enable debug mode.
-		logger => q(Zabbix.ServerScript), 	# Log4perl logger name
-		api => q(),				# name of Zabbix API instance in global config
-		id => q(),	 			# unique identifier of what is being done, e.g.: database being checked
-		unique => 1, 				# only one instance for each $opt->{id} is allowed
-	}
-
 =head2 return_value($value)
 
 Prints $value to STDOUT and exits. Throws an exception if $value is not defined.
